"use strict";
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);

// src/index.ts
var index_exports = {};
__export(index_exports, {
  useBattery: () => useBattery,
  useClickOutside: () => useClickOutside,
  useIsBrowser: () => useIsBrowser,
  useIsServer: () => useIsServer
});
module.exports = __toCommonJS(index_exports);

// src/hooks/useIsBrowser.ts
var import_react = require("react");
function useIsBrowser() {
  const [isBrowser, setIsBrowser] = (0, import_react.useState)(false);
  (0, import_react.useEffect)(() => {
    setIsBrowser(true);
  }, []);
  return isBrowser;
}

// src/hooks/useIsServer.ts
var import_react2 = require("react");
function useIsServer() {
  const [isServer, setIsServer] = (0, import_react2.useState)(true);
  (0, import_react2.useEffect)(() => {
    setIsServer(false);
  }, []);
  return isServer;
}

// src/hooks/useBattery.ts
var import_react3 = require("react");
function useBattery() {
  const [state, setState] = (0, import_react3.useState)({
    isSupported: false,
    isLoading: true,
    error: null,
    battery: null
  });
  (0, import_react3.useEffect)(() => {
    if (!navigator || !("getBattery" in navigator)) {
      setState({
        isSupported: false,
        isLoading: false,
        error: null,
        battery: null
      });
      return;
    }
    let batteryManager = null;
    let isComponentMounted = true;
    const updateBatteryState = (manager) => {
      if (!isComponentMounted) return;
      if (!manager) {
        setState((prev) => ({
          ...prev,
          isLoading: false,
          error: new Error("Could not access battery information"),
          battery: null
        }));
        return;
      }
      setState({
        isSupported: true,
        isLoading: false,
        error: null,
        battery: {
          charging: manager.charging,
          chargingTime: manager.chargingTime,
          dischargingTime: manager.dischargingTime,
          level: manager.level,
          connected: manager.charging || manager.level === 1 && manager.chargingTime === 0
        }
      });
    };
    const setupBatteryListeners = (manager) => {
      if (!manager) return;
      manager.addEventListener(
        "chargingchange",
        () => updateBatteryState(manager)
      );
      manager.addEventListener(
        "chargingtimechange",
        () => updateBatteryState(manager)
      );
      manager.addEventListener(
        "dischargingtimechange",
        () => updateBatteryState(manager)
      );
      manager.addEventListener(
        "levelchange",
        () => updateBatteryState(manager)
      );
      batteryManager = manager;
    };
    const getBatteryInfo = async () => {
      try {
        const manager = await navigator.getBattery();
        if (isComponentMounted) {
          updateBatteryState(manager);
          setupBatteryListeners(manager);
        }
      } catch (error) {
        if (isComponentMounted) {
          setState({
            isSupported: true,
            // API exists but there was an error
            isLoading: false,
            error: error instanceof Error ? error : new Error("Unknown battery error"),
            battery: null
          });
        }
      }
    };
    getBatteryInfo();
    return () => {
      isComponentMounted = false;
      if (batteryManager) {
        batteryManager.removeEventListener(
          "chargingchange",
          updateBatteryState
        );
        batteryManager.removeEventListener(
          "chargingtimechange",
          updateBatteryState
        );
        batteryManager.removeEventListener(
          "dischargingtimechange",
          updateBatteryState
        );
        batteryManager.removeEventListener("levelchange", updateBatteryState);
      }
    };
  }, []);
  return state;
}

// src/hooks/useClickOutside.ts
var import_react4 = require("react");
var import_react5 = require("react");
function useClickOutside(onClickOutside, options = {}) {
  const {
    enabled = true,
    ignoreRefs = [],
    mouseEvents = ["mousedown"],
    listenForTouchEvents = true,
    ignoreScrollbar = true
  } = options;
  const ref = (0, import_react4.useRef)(null);
  const handleClickOutside = (0, import_react4.useCallback)(
    (event) => {
      if (!enabled) return;
      const target = event.target;
      if (ignoreScrollbar && event instanceof MouseEvent) {
        if (event.clientX >= document.documentElement.clientWidth) {
          return;
        }
      }
      if (ref.current && ref.current.contains(target)) {
        return;
      }
      for (const ignoreRef of ignoreRefs) {
        if (ignoreRef.current && ignoreRef.current.contains(target)) {
          return;
        }
      }
      onClickOutside(event);
    },
    [enabled, ignoreRefs, ignoreScrollbar, onClickOutside]
  );
  (0, import_react4.useEffect)(() => {
    if (!enabled) return;
    mouseEvents.forEach((mouseEvent) => {
      document.addEventListener(
        mouseEvent,
        handleClickOutside
      );
    });
    if (listenForTouchEvents) {
      document.addEventListener(
        "touchstart",
        handleClickOutside
      );
    }
    return () => {
      mouseEvents.forEach((mouseEvent) => {
        document.removeEventListener(
          mouseEvent,
          handleClickOutside
        );
      });
      if (listenForTouchEvents) {
        document.removeEventListener(
          "touchstart",
          handleClickOutside
        );
      }
    };
  }, [enabled, mouseEvents, listenForTouchEvents, handleClickOutside]);
  return ref;
}
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {
  useBattery,
  useClickOutside,
  useIsBrowser,
  useIsServer
});
